/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var Native = function() {
    var app, $$, theDevice;
    var pictureSource, destinationType;
    var handleDeviceReady = function(selector) {
        document.addEventListener('deviceready', function() {
            theDevice = device;
            StatusBar.backgroundColorByHexString(typeof device!=='undefined' && device.platform==='Android'?'#000000':'#f7f7f8');
            StatusBar.styleDefault();
            StatusBar.show();
            $$(document).find('.tabbar-demo-icon-post').addClass('shadow');
            console.log('Device Name: ' + device.name + '\n' +
                        'Device PhoneGap: ' + device.phonegap + '\n' +
                        'Device Platform: ' + device.platform + '\n' +
                        'Device UUID: ' + device.uuid + '\n' +
                        'Device Version: ' + device.version + '\n' +
                        'Device Model: ' + device.model + '\n');
            pictureSource=navigator.camera.PictureSourceType;
    		destinationType=navigator.camera.DestinationType;
            //navigator.notification.vibrate(1000);
            if (!native.isConnected()) {
                navigator.notification.alert('当前网络不可用，请检查你的网络设置',null,'工程家','好');
            }
        }, false);
        document.addEventListener("online", function() {
            console.log('online');
        },false);
        document.addEventListener("offline", function() {
            console.log('offline');
        },false);
        // window.addEventListener('statusTap', function() {
        //     // scroll-up with  or do whatever you want
        //     document.body.scrollTop = 0;
        //     console.log('statusTap');
        // });
    }
    // camera //////////////////////////////////////////////////////////////////
    var smallImageSelector = '.smallImage', largeImageSelector = '.largeImage';
    var onPhotoDataSuccess = function(imageData) {
        // 当成功获得一张照片的Base64编码数据后被调用
        // 取消注释以查看Base64编码的图像数据
        // 显示拍摄的照片
        $$(document).find(smallImageSelector).attr('src', imageData);//"data:image/jpeg;base64," + imageData;
    }
    var onPhotoFail = function(message) {
        console.log('Failed because: ' + message);
    }
    // 当成功得到一张照片的URI后被调用
    var onPhotoURISuccess = function (imageURI) {
 		// 取消注释以查看图片文件的URI
 		// 获取图片句柄
        $$(document).find(largeImageSelector).attr('src', imageURI);
 	}
    var getPhoto = function (source, selector) {
        largeImageSelector = selector;
    	// 从设定的来源处获取图像文件URI
 		navigator.camera.getPicture(onPhotoURISuccess, onPhotoFail, {
            quality: 50,
            destinationType: destinationType.FILE_URI,
            sourceType: source
        });
    }
    // Acceleration ////////////////////////////////////////////////////////////
    var accelTimer, compassTimer, geoTimer;

    // captureAudio ////////////////////////////////////////////////////////////
    // Called when capture operation is finished
    var captureSuccess = function (mediaFiles) {
         var i, len;
         for (i = 0, len = mediaFiles.length; i < len; i += 1) {
             uploadFile(mediaFiles[i]);
         }
     }
     // Called if something bad happens.
     var captureError = function (error) {
         var msg = 'An error occurred during capture: ' + error.code;
         navigator.notification.alert(msg, null, 'Uh oh!');
     }
     // Upload files to server
     var uploadFile = function (mediaFile) {
         var ft = new FileTransfer(),
             path = mediaFile.fullPath,
             name = mediaFile.name;
             console.log('path : ' + path + ', name : ' + name);
         ft.upload(path,
             "http://my.domain.com/upload.php",
             function(result) {
                 console.log('Upload success: ' + result.responseCode);
                 console.log(result.bytesSent + ' bytes sent');
             },
             function(error) {
                 console.log('Error uploading file ' + path + ': ' + error.code);
             },
             { fileName: name });
    }
    return {
        init: function(aApp, aDom7) {
            app = aApp;
            $$ = aDom7;
            handleDeviceReady('#deviceready');
            return this;
        },
        getDevice: function() {
            return theDevice;
        },
        // camera //////////////////////////////////////////////////////////////
        takePhoto: function (successCallback, failCallback) {
            smallImageSelector = successCallback;
     		// 使用设备上的摄像头拍照，并获得Base64编码字符串格式的图像
     		navigator.camera.getPicture(
                typeof successCallback === 'function' ? successCallback : onPhotoDataSuccess,
                typeof failCallback === 'function' ? failCallback : onPhotoFail,
                { quality: 50 }
            );
        },
        takePhotoEdit: function (selector) {
            smallImageSelector = selector;
            // 使用设备上的摄像头拍照，并获得Base64编码字符串格式的可编辑图像
            navigator.camera.getPicture(onPhotoDataSuccess, onPhotoFail, { quality: 20, allowEdit: true });
        },
        openPhotoLibrary: function (selector) {
            getPhoto(pictureSource.PHOTOLIBRARY, selector);
        },
        openPhotoAlbum: function(selector) {
            getPhoto(pictureSource.SAVEDPHOTOALBUM, selector);
        },
        // connection //////////////////////////////////////////////////////////
        checkConnection: function () {
            var networkState = navigator.connection.type;
            var states = {};
            states[Connection.UNKNOWN]  = 'Unknown connection';
            states[Connection.ETHERNET] = 'Ethernet connection';
            states[Connection.WIFI]     = 'WiFi connection';
            states[Connection.CELL_2G]  = 'Cell 2G connection';
            states[Connection.CELL_3G]  = 'Cell 3G connection';
            states[Connection.CELL_4G]  = 'Cell 4G connection';
            states[Connection.CELL]     = 'Cell generic connection';
            states[Connection.NONE]     = 'No network connection';
            navigator.notification.alert('Connection type: ' + states[networkState]);
        },
        isConnected: function() {
            return [Connection.UNKNOWN,Connection.NONE].indexOf(navigator.connection.type)<0;
        },
        // Acceleration ////////////////////////////////////////////////////////
        getCurrentAcceleration: function(selector) {
            if ((object=$$(document).find(selector)).hasClass('timer')) {
                console.log('getCurrentAcceleration remove timer');
                clearInterval(accelTimer);
                object.removeClass('timer');
                return;
            } else {
                object.addClass('timer');
                console.log('getCurrentAcceleration add timer');
                accelTimer = setInterval(function () {
                    navigator.accelerometer.getCurrentAcceleration(function(acceleration){
                        object.html(
                            'Acceleration X: ' + acceleration.x + '<br>' +
                            'Acceleration Y: ' + acceleration.y + '<br>' +
                            'Acceleration Z: ' + acceleration.z + '<br>' +
                            'Timestamp: '      + acceleration.timestamp + '<br>');
                    }, function(){
                      object.html('onError!');
                    });
                },500);
            }
        },
        // captureAudio ////////////////////////////////////////////////////////
        captureAudio: function () {
            // Launch device audio recording application,
            // allowing user to capture up to 2 audio clips
            navigator.device.capture.captureAudio(captureSuccess, captureError, {limit: 2});
        },
        // Compass /////////////////////////////////////////////////////////////
        getCompass: function(selector) {
            if ((object=$$(document).find(selector)).hasClass('timer')) {
                console.log('getCompass remove timer');
                clearInterval(compassTimer);
                object.removeClass('timer');
                return;
            } else {
                object.addClass('timer');
                console.log('getCompass add timer');
                compassTimer = setInterval(function () {
                    navigator.compass.getCurrentHeading(function(heading) {
                        object.html('Heading: ' + heading.magneticHeading);
                    }, function(compassError) {
                        object.html('Compass Error: ' + compassError.code);
                    });
                },500);
            }
        },
        getContact: function(successCallback, failCallback) {
            var options = new ContactFindOptions();
            options.filter = "";
            options.multiple = true;
            var fields = ["displayName", "name", "phoneNumbers"];
            navigator.contacts.find(fields, typeof successCallback === 'function' ? successCallback : function(contacts) {
                // 返回格式
                // [{"id":38,"rawId":null,"displayName":null,"name":{"givenName":"菊兰","honorificSuffix":null,"formatted":"黄菊兰","middleName":null,"familyName":"黄","honorificPrefix":null},"nickname":"大姐","phoneNumbers":[{"value":"18859221689","pref":false,"id":0,"type":"mobile"}],"emails":null,"addresses":null,"ims":null,"organizations":null,"birthday":null,"note":null,"photos":null,"categories":null,"urls":null}]
                // console.log(JSON.stringify(contacts));
                var html='';
                for (var i = 0; i < contacts.length; i++) {
                    // console.log("Name = " + contacts[i].name.formatted + ", phoneNumbers = " + contacts[i].phoneNumbers[0].value);
                    html += "<li>Name = "+contacts[i].name.formatted+", phoneNumbers = " + contacts[i].phoneNumbers[0].value+"</li>";
                }
                $$(document).find(successCallback).html('<ul>'+html+'</ul>');
            }, failCallback!==undefined ? failCallback : function(contactError) {
                alert('onError!');
            }, options);
        },
        getGeolocation: function(selector) {
            if ((object=$$(document).find(selector)).hasClass('timer')) {
                console.log('getGeolocation remove timer');
                clearInterval(geoTimer);
                object.removeClass('timer');
                return;
            } else {
                object.addClass('timer');
                console.log('getGeolocation add timer');
                geoTimer = setInterval(function () {
                    navigator.geolocation.getCurrentPosition(function(position) {
                        object.html('Latitude: '+ position.coords.latitude+ '\n' +
                                    'Longitude: '+ position.coords.longitude+ '\n' +
                                    'Altitude: '+ position.coords.altitude+ '\n' +
                                    'Accuracy: '+ position.coords.accuracy+ '\n' +
                                    'Altitude Accuracy: ' + position.coords.altitudeAccuracy+ '\n' +
                                    'Heading: '+ position.coords.heading+ '\n' +
                                    'Speed: '+ position.coords.speed+ '\n' +
                                    'Timestamp: '+ position.timestamp+ '\n');
                    }, function(error) {
                        object.html('code: '    + error.code    + '\n' +
                                    'message: ' + error.message + '\n');
                    });
                },500);
            }
        },
        barcodeScanner: function(successCallback, failCallback) {
            var options = {
                "preferFrontCamera" : false, // iOS and Android
                "showFlipCameraButton" : true, // iOS and Android
                "showTorchButton" : true, // iOS and Android
                "disableAnimations" : false, // iOS
                "prompt" : "Place a barcode inside the scan area", // supported on Android only
                "formats" : "QR_CODE,PDF_417", // default: all but PDF_417 and RSS_EXPANDED
                "orientation" : "portrait" // Android only (portrait|landscape), default unset so it rotates with the device
            };
            cordova.plugins.barcodeScanner.scan(
    	      typeof successCallback === 'function' ? successCallback : function (result) {
    	          $$(document).find(successCallback).html("We got a barcode\n" +
    	                "Result: " + result.text + "\n" +
    	                "Format: " + result.format + "\n" +
    	                "Cancelled: " + result.cancelled);
    	      },
    	      failCallback!==undefined ? failCallback : function (error) {
    	          $$(document).find(selector).html("Scanning failed: " + error);
    	      },options
    	   );
        },
    }
}();
var native = Native.init(myApp, $$);
